package Bundle::Locale::CLDR::World;

use version;

our $VERSION = version->declare('v0.44.0');

=head1 NAME

Bundle::Locale::CLDR::World

=head1 CONTENTS

Locale::CLDR::Locales::Ar 0.44.0

Locale::CLDR::Locales::Eo 0.44.0

Locale::CLDR::Locales::Ia 0.44.0

Locale::CLDR::Locales::Io 0.44.0

Locale::CLDR::Locales::Vo 0.44.0

Bundle::Locale::CLDR::Asia 0.44.0

Locale::CLDR::Locales::Jbo 0.44.0

Locale::CLDR::Locales::Tok 0.44.0

Bundle::Locale::CLDR::Africa 0.44.0

Bundle::Locale::CLDR::Europe 0.44.0

Bundle::Locale::CLDR::Oceania 0.44.0

Bundle::Locale::CLDR::Americas 0.44.0

Bundle::Locale::CLDR::Eurozone 0.44.0

Locale::CLDR::Locales::Ar::Arab 0.44.0

Locale::CLDR::Locales::Eo::Latn 0.44.0

Locale::CLDR::Locales::Ia::Latn 0.44.0

Locale::CLDR::Locales::Io::Latn 0.44.0

Locale::CLDR::Locales::Vo::Latn 0.44.0

Locale::CLDR::Locales::Jbo::Latn 0.44.0

Locale::CLDR::Locales::Tok::Latn 0.44.0

Bundle::Locale::CLDR::Europeanunion 0.44.0

Bundle::Locale::CLDR::Unitednations 0.44.0

Locale::CLDR::Locales::Ar::Arab::001 0.44.0

Locale::CLDR::Locales::En::Latn::001 0.44.0

Locale::CLDR::Locales::En::Latn::150 0.44.0

Locale::CLDR::Locales::Eo::Latn::001 0.44.0

Locale::CLDR::Locales::Ia::Latn::001 0.44.0

Locale::CLDR::Locales::Io::Latn::001 0.44.0

Locale::CLDR::Locales::Vo::Latn::001 0.44.0

Locale::CLDR::Locales::Jbo::Latn::001 0.44.0

Locale::CLDR::Locales::Tok::Latn::001 0.44.0


=cut

1;

